rule win_montysthree_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.montysthree."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.montysthree"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ff15???????? 8bf0 3bf3 89754c }
            // n = 4, score = 200
            //   ff15????????         |                     
            //   8bf0                 | mov                 esi, eax
            //   3bf3                 | cmp                 esi, ebx
            //   89754c               | mov                 dword ptr [ebp + 0x4c], esi

        $sequence_1 = { 8bd4 46 62807013e64e 13e6 d1b660d40c3e }
            // n = 5, score = 200
            //   8bd4                 | mov                 edx, esp
            //   46                   | inc                 esi
            //   62807013e64e         | bound               eax, qword ptr [eax + 0x4ee61370]
            //   13e6                 | adc                 esp, esi
            //   d1b660d40c3e         | sal                 dword ptr [esi + 0x3e0cd460], 1

        $sequence_2 = { 8d4d70 e8???????? ff30 687b020000 57 68???????? e8???????? }
            // n = 7, score = 200
            //   8d4d70               | lea                 ecx, [ebp + 0x70]
            //   e8????????           |                     
            //   ff30                 | push                dword ptr [eax]
            //   687b020000           | push                0x27b
            //   57                   | push                edi
            //   68????????           |                     
            //   e8????????           |                     

        $sequence_3 = { ff75f0 ffd6 8bc7 f7d8 }
            // n = 4, score = 200
            //   ff75f0               | push                dword ptr [ebp - 0x10]
            //   ffd6                 | call                esi
            //   8bc7                 | mov                 eax, edi
            //   f7d8                 | neg                 eax

        $sequence_4 = { 50 bf00040000 57 ff15???????? 85c0 8d8574f7ffff 7405 }
            // n = 7, score = 200
            //   50                   | push                eax
            //   bf00040000           | mov                 edi, 0x400
            //   57                   | push                edi
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   8d8574f7ffff         | lea                 eax, [ebp - 0x88c]
            //   7405                 | je                  7

        $sequence_5 = { ff7508 53 ff15???????? 53 8d83080a0000 50 }
            // n = 6, score = 200
            //   ff7508               | push                dword ptr [ebp + 8]
            //   53                   | push                ebx
            //   ff15????????         |                     
            //   53                   | push                ebx
            //   8d83080a0000         | lea                 eax, [ebx + 0xa08]
            //   50                   | push                eax

        $sequence_6 = { 8d4d28 e8???????? 50 68???????? e8???????? }
            // n = 5, score = 200
            //   8d4d28               | lea                 ecx, [ebp + 0x28]
            //   e8????????           |                     
            //   50                   | push                eax
            //   68????????           |                     
            //   e8????????           |                     

        $sequence_7 = { 8933 39753c 8b457c 8930 753d 39756c }
            // n = 6, score = 200
            //   8933                 | mov                 dword ptr [ebx], esi
            //   39753c               | cmp                 dword ptr [ebp + 0x3c], esi
            //   8b457c               | mov                 eax, dword ptr [ebp + 0x7c]
            //   8930                 | mov                 dword ptr [eax], esi
            //   753d                 | jne                 0x3f
            //   39756c               | cmp                 dword ptr [ebp + 0x6c], esi

        $sequence_8 = { e8???????? 8d8570fdffff 50 8d4dc4 }
            // n = 4, score = 200
            //   e8????????           |                     
            //   8d8570fdffff         | lea                 eax, [ebp - 0x290]
            //   50                   | push                eax
            //   8d4dc4               | lea                 ecx, [ebp - 0x3c]

        $sequence_9 = { ff756c ff15???????? 8d4524 50 8d4d4c e8???????? eb25 }
            // n = 7, score = 200
            //   ff756c               | push                dword ptr [ebp + 0x6c]
            //   ff15????????         |                     
            //   8d4524               | lea                 eax, [ebp + 0x24]
            //   50                   | push                eax
            //   8d4d4c               | lea                 ecx, [ebp + 0x4c]
            //   e8????????           |                     
            //   eb25                 | jmp                 0x27

    condition:
        7 of them and filesize < 458752
}